// Simulation to compare stcox and stpm3
// This will do simplied version of a simulation study to assess
// how well splines capture complex shapes
//
// See https://doi.org/10.1080/00949655.2013.845890

frames reset

// We will generate data from a mixture weibull distribution
// parameters (feel free to change these)
global lambda1 0.4
global lambda2 0.3
global gamma1 0.4
global gamma2 1.7
global pmix 0.4
global loghr = ln(1.3)

// define survival and hazard functions for mixture weibull
global S1 exp(-$lambda1*x^$gamma1)
global S2 exp(-$lambda2*x^$gamma2)
global h1 $lambda1*$gamma1*x^($gamma1-1)
global h2 $lambda2*$gamma2*x^($gamma2-1)

// See what the true hazard and survival functions look like
twoway function y = ($pmix*$h1*$S1 + (1-$pmix)*$h2*$S2)/ ///
                    ($pmix*$S1 + (1-$pmix)*$S2)          ///
                    , range(0 5)                         ///
                    title("hazard function")             ///
                    ylabel(0(0.2)1, format(%3.1f))       ///
                    name(ht, replace)

twoway function y = ($pmix*$S1 + (1-$pmix)*$S2)          ///
                    , range(0 5)                         ///
                    title("survival function")           ///
                    ylabel(0(0.2)1, format(%3.1f))       ///
                    name(St, replace)

// Generate a single simulated dataset using survsim
// 1000 observations
clear 
set seed 2727
set obs 1000
gen trt=rbinomial(1,0.5)
survsim time died, dist(weibull) mixture pmix($pmix) ///
                   lambdas($lambda1 $lambda2) gammas($gamma1 $gamma2) ///
                   maxtime(5) cov(trt $loghr)

// stset & non-parametric smoother for hazard function
stset time, f(died==1)
sts graph, hazard kernel(epan2) ylabel(0(0.2)1)

// Fit stpm3 and stcox models
stpm3 i.trt, scale(lncumhazard) df(4)
est store stpm3
stcox i.trt, 
est store stcox

// compare estimates and standard errors
// What is your expectation here?
est tab stpm3 stcox, eq(1) se
              
              
// Now perform simulation study comparing 100 datasets
// We will store results in a frame
// We will store the following:
//     -- log hazard ratios
//     -- se of log hazard ratio
//     -- baseline survival at 5 years
frame create simresults simnum beta_stpm3 se_stpm3 S5_stpm3 ///
                               beta_stcox se_stcox S5_stcox

// loop for 100 simulations
// sample size 1000
forvalues i = 1/100 {
  qui {
    clear
    // generate data
    set obs 1000
    gen trt=rbinomial(1,0.5)
    survsim time died, dist(weibull) mixture pmix($pmix) ///
                       lambdas($lambda1 $lambda2) gammas($gamma1 $gamma2) ///
                       maxtime(5) cov(trt $loghr)
    stset time, failure(died=1)
    // stpm3 model
    stpm3 i.trt, scale(lncumhazard) df(5) initvaluesloop
    local beta_stpm3 = _b[1.trt]
    local se_stpm3   = _se[1.trt]
    gen t5 = 5 in 1
    predict S5, surv timevar(t5) at1(trt 0) merge
    local S5_stpm3 = S5[1]
    // stcox model
    stcox i.trt, 
    local beta_stcox = _b[1.trt]
    local se_stcox   = _se[1.trt]
    predict basesurv, basesurv
    summ basesurv if _t==5
    local S5_stcox `r(mean)'
    // save results
    frame post simresults (`i') (`beta_stpm3') (`se_stpm3') (`S5_stpm3') ///
                                (`beta_stcox') (`se_stcox') (`S5_stcox')
  }
  di "Simulation `i'"
}

// look at simulations results
frame change simresults
// list first 10 rows
list in 1/10
// simple comparisons
compare beta*
corr beta*

// scatter of beta estimates
twoway (scatter beta_stpm3 beta_stcox, color(%30)) ///
       (function y = x, range(beta_stcox))         ///
       , xtitle(stcox) ytitle(stpm3)               ///
       legend(off)                                 ///
       title(log hazards ratios)                   ///
       name(loghr, replace)

// scatter of standard errors
twoway (scatter se_stpm3 se_stcox, color(%30)) ///
       (function y = x, range(se_stcox))       ///
       , xtitle(stcox) ytitle(stpm3)           ///
       legend(off)                             ///
       title(standard errors)                  ///
       name(loghr_se, replace)
              
// scatter of survival at 5 years
twoway (scatter S5_stpm3 S5_stcox, color(%30)) ///
       (function y = x, range(S5_stcox))       ///
       , xtitle(stcox) ytitle(stpm3)           ///
       legend(off)                             ///
       title(Survival at 5 years)              ///
       name(S5, replace)
       
// This is a simulation study we know the true values,
// so we can access bias.
global trueS5 = $pmix*exp(-$lambda1*5^$gamma1) +   ///
                (1-$pmix)*exp(-$lambda2*5^$gamma2) 
                
gen S5_stpm3_diff = S5_stpm3 - $trueS5               
gen S5_stcox_diff = S5_stcox - $trueS5               
summ S5_stpm3_diff S5_stcox_diff    

// NOTE: we should really simulate more datasets   
   