// This file produces stpm3 output with time-dependent effects
// Paul Lambert 2023-05-06

clear all
set scheme fpsaus_c
global dofile stpm3_breast_EW50_non_linear_functions

use breast_EW50 if agediag<=50 & inlist(dep,1,5)
stset survtime, failure(dead==1) exit(time 5)
stpm3 i.dep, scale(lncumhazard) df(5) tvc(i.dep) dftvc(3) ///
             eform nolog vsquish

list dep _t 5.dep#c.(_ns_tvc*) in 1/7,noobs


predict h0tvc h5tvc, hazard frame(hpred, replace) per(1000) ci ///
                     timevar(0 5, step(0.025))                 ///
                     at1(dep 1) at2(dep 5)                  ///
                     contrast(ratio) contrastvar(hr)
               
// Fit PH model for comparison
stpm3 i.dep, scale(lncumhazard) df(5) eform nolog 
predict h0ph h5ph, hazard frame(hpred, merge) per(1000) ///
                   at1(dep 1) at2(dep 5)
                     
// plot hazards                   
frame hpred {
  twoway (line h0tvc h5tvc tt) ///
         (line h0ph h5ph tt, pstyle(p1line p2line) lpattern(dash..) lwidth(*0.5..)) ///
         , xtitle("Years from diagnosis")                                           ///
         ytitle("Mortality rate (per 1000 py)")                                     ///
         ylabel(0(20)100)                                                           ///
         legend(order(1 "Least deprived (TVC)" 2 "Most deprived (TVC)"              ///
                      3 "Least deprived (PH)"  4 "Most deprived (PH)") pos(5))      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}  
                   
// plot hazard ratio                   
frame hpred {
  twoway (line hr tt)                                                      ///
         (rarea hr_lci hr_uci tt, pstyle(p1line) color(%30))               ///
         , xtitle("Years from diagnosis")                                  ///
         ytitle("Hazard (mortality rate) ratio")                           ///
         ylabel(, format(%3.1f))                                           ///
         yline(`=exp(_b[5.dep])', lcolor(black) lpattern(dash))            ///
         legend(off)                                                       ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}  

capture frame drop hr_df



// sensitivity to knots
capture frame drop hr_df
forvalues i = 1/3 {
  stpm3 i.dep, scale(lncumhazard) df(5) tvc(i.dep) dftvc(`i') ///
             eform nolog vsquish
  estimates store tvc_df`i'           
  predict , hazard ci frame(hr_df, mergecreate)  ///
            timevar(0 5, step(0.1))                   ///
            at1(dep 1) at2(dep 5)                     ///
            contrast(ratio) contrastvar(hr`i') nogen  
}

forvalues i = 1/3 {
  estimates restore tvc_df`i'
  count if _d
  estimates stats
  local AIC`i': display %6.1f el(r(S),1,5)
  local BIC`i': display %6.1f el(r(S),1,6)
}

frame hr_df {
  twoway (line hr1* tt, lpattern(solid dash dash) lwidth(medium thin thin) pstyle(p1line..)) ///
         (line hr2* tt, lpattern(solid dash dash) lwidth(medium thin thin) pstyle(p2line..)) ///
         (line hr3* tt, lpattern(solid dash dash) lwidth(medium thin thin) pstyle(p3line..)) ///
         , xtitle("Years from diagnosis")                                                    ///
         ytitle("Hazard (mortality rate) ratio")                                             ///
         legend(order(1 "1 df (AIC=`AIC1', BIC=`BIC1')"                                      ///
                      4 "2 df (AIC=`AIC2', BIC=`BIC2')"                                      ///
                      7 "3 df (AIC=`AIC3', BIC=`BIC3')"))                                    ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}



                   
