// The file demonstrates contrasts when making predictions
// Paul Lambert 2024-08-08

clear all
set scheme fpsaus_c
global dofile stpm3_predictions_contrasts

use breast_EW50 

stset survtime, failure(dead==1) exit(time 5)

stpm3 i.dep agediag, scale(lncumhazard) df(5) eform nolog neq(1)

  
predict S40_dep1 S40_dep5, survival ci frame(survpred, replace) ///
        timevar(0 5, step(0.1))                                 ///
        at1(dep 1 agediag 40) at2(dep 5 agediag 40)             ///
        contrast(difference) contrastvar(Sdiff) 
  
frame survpred {
  twoway (line S40_dep1 S40_dep5 tt)                                      ///
         (rarea S40_dep1_lci S40_dep1_uci tt, pstyle(p1line) color(%30))  ///
         (rarea S40_dep5_lci S40_dep5_uci tt, pstyle(p2line) color(%30)), ///
         xtitle("Years from diagnosis")                                   ///
         ytitle("S(t)")                                                   ///
         ylabel(, format(%3.1f))                                          ///
         legend(order(1 "Least deprived" 2 "Most deprived"))              ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}    
  
frame survpred {
  twoway (line Sdiff tt)                                            ///
         (rarea Sdiff_lci Sdiff_uci tt, pstyle(p1line) color(%30)), ///
         xtitle("Years from diagnosis")                             ///
         ytitle("Difference in survival functions")                 ///
         ylabel(, format(%3.2f))                                    ///
         legend(off)                                                ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}  
  
  
predict F40_dep1 F40_dep5, failure ci frame(Fpred, replace)     ///
        timevar(0 5, step(0.1))                                 ///
        at1(dep 1 agediag 40) at2(dep 5 agediag 40)             ///
        contrast(ratio) contrastvar(Fdiff) 
        
frame Fpred {
  twoway (line Fdiff tt)                                            ///
         (rarea Fdiff_lci Fdiff_uci tt, pstyle(p1line) color(%30)), ///
         xtitle("Years from diagnosis")                             ///
         ytitle("Difference in survival functions")                 ///
         ylabel(, format(%3.2f))                                    ///
         legend(off)                                                ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}    
  
  
  
predict h40_dep1 h40_dep5, hazard ci frame(hazpred, replace) per(1000) ///
        timevar(0.1 5, step(0.1))                                      ///
        at1(dep 1 agediag 40)                                          ///
        at2(dep 5 agediag 40)                                          ///
        contrast(difference) contrastvar(hd40_dep)
        
frame hazpred {
  twoway (line hd40_dep tt)                                               ///
         (rarea hd40_dep_lci hd40_dep_uci tt, pstyle(p1line) color(%30)), ///  
         ylabel(0(5)25)                                                   ///
         xtitle("Years from diagnosis")                                   ///
         ytitle("Difference in mortality rate (per 1000 py)")             ///
         legend(off)                                                      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}







        
frame survpred {
  twoway (line S40_dep1 S40_dep5 tt),                               ///
         xtitle("Years from diagnosis")                             ///
         ytitle("Probability Alive")                                ///
         ylabel(0(0.2)1, format(%3.1f))                             ///
         title("Predicted Survival for a 40 year old")              ///
         legend(order(1 "Least deprived" 2 "Most deprived") pos(9)) ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}        

// predicting for a range of ages
capture frame drop agepred

frame create agepred
frame agepred {
  range agediag 18 99 82
  gen dep = .
  gen t5 = 5
  predict S_dep1 S_dep5, surv ci timevar(t5) merge   ///
         at1(dep 1, obsvalues) at2(dep 5, obsvalues)
}

frame agepred {
  twoway (line S_dep1 S_dep5 agediag)                                      ///
         (rarea S_dep1_lci S_dep1_uci agediag, pstyle(p1line) color(%30))  ///
         (rarea S_dep5_lci S_dep5_uci agediag, pstyle(p2line) color(%30))  ///
         , legend(order(1 "Least Deprived" 2 "Most deprived")              ///
         cols(1) pos(11))                                                  ///
         ylabel(0.4(0.1)1, format(%3.1f))                                  ///
         ytitle("Survival at 5 years")                                     ///
         xtitle("Age at diagnosis")                                    ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}

range tt 0 5 101
standsurv , survival at1(.) timevar(tt) ci atvar(Sm) frame(msurv, replace)
sts graph, noshow plotopts(lwidth(*3) lcolor(%40))
frame msurv: addplot: line Sm tt, lcolor(%100)

sts graph, noshow plotopts(lwidth(*3) lcolor(%40)) ///
note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
frame msurv: addplot: line Sm tt, lcolor(%100)

stpm3km
stpm3km, note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))


stpm3km agediag, groups(4)
stpm3km agediag, groups(4) ///
note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

// Fit a more complex model
stpm3 i.dep @ns(agediag,df(3)), scale(lncumhazard) df(5) eform nolog 

stpm3km
stpm3km, ///
note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

stpm3km agediag, groups(4)
stpm3km agediag, groups(4) ///
note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

// marginal contrast
stpm3 i.dep agediag, scale(lncumhazard) df(5) eform nolog neq(1)

standsurv, survival ci timevar(tt) frame(msdiff, replace)  ///
           at1(dep 1) at2(dep 5)                           ///
           atvar(S1 S5)                                    ///
           contrast(difference)                            ///
           contrastvar(Sdiff)

           
frame msdiff {
  twoway (line S1 S5 tt)                                     ///
         (rarea S1_lci S1_uci tt, pstyle(p1line) color(%30))  ///
         (rarea S5_lci S5_uci tt, pstyle(p2line) color(%30)) ///
         , xtitle("Years from diagnosis")                      ///
         ytitle("Stanardized survival functions")          ///
         ylabel(, format(%3.2f))                             ///
         legend(off)                                         ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
} 
           
frame msdiff {
  twoway (line Sdiff tt)                                            ///
         (rarea Sdiff_lci Sdiff_uci tt, pstyle(p1line) color(%30)), ///
         xtitle("Years from diagnosis")                             ///
         ytitle("Difference in survival functions")                 ///
         ylabel(, format(%3.2f))                                    ///
         legend(off)                                                ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
} 

// rmst
gen t5 = 5 in 1
standsurv, rmst ci timevar(t5)      ///
           frame(rmst, replace)     ///
           at1(dep 1) at2(dep 5)    ///
           atvar(rmst1 rmst5)       ///
           contrast(difference)     ///
           contrastvar(rmstdiff)

frame rmst: list rmst1* rmst5*, noobs
frame rmst: list rmstdiff*, noobs


